@@ -30,6 +30,7 @@ class FakeShareClient(object):
         self.auth_token = kwargs['token']
         self.management_url = kwargs['endpoint']
         self.shares = mock.Mock()
+        self.transfers = mock.Mock()
         self.share_access_rules = mock.Mock()
         self.share_groups = mock.Mock()
         self.share_types = mock.Mock()
@@ -37,6 +38,7 @@ class FakeShareClient(object):
         self.quotas = mock.Mock()
         self.quota_classes = mock.Mock()
         self.share_snapshots = mock.Mock()
+        self.share_group_snapshots = mock.Mock()
         self.share_snapshot_export_locations = mock.Mock()
         self.share_snapshot_instances = mock.Mock()
         self.share_replicas = mock.Mock()
@@ -58,6 +60,7 @@ class FakeShareClient(object):
         self.limits = mock.Mock()
         self.share_group_types = mock.Mock()
         self.share_group_type_access = mock.Mock()
+        self.share_servers = mock.Mock()
 
 
 class ManilaParseException(Exception):
@@ -583,6 +586,64 @@ class FakeShareSnapshot(object):
         return share_snapshots
 
 
+class FakeShareTransfer(object):
+    """Fake a share transfer"""
+
+    @staticmethod
+    def create_one_transfer(attrs=None, methods=None):
+        """Create a fake share transfer
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :return:
+            A FakeResource object, with id, resource and so on
+        """
+
+        attrs = attrs or {}
+        methods = methods or {}
+        now_time = datetime.datetime.now()
+        delta_time = now_time + datetime.timedelta(minutes=5)
+
+        share_transfer = {
+            'accepted': 'False',
+            'auth_key': 'auth-key-' + uuid.uuid4().hex,
+            'created_at': now_time.isoformat(),
+            'destination_project_id': None,
+            'expires_at': delta_time.isoformat(),
+            'id': 'transfer-id-' + uuid.uuid4().hex,
+            'name': 'name-' + uuid.uuid4().hex,
+            'resource_id': 'resource-id-' + uuid.uuid4().hex,
+            'resource_type': 'share',
+            'source_project_id': 'source-project-id-' + uuid.uuid4().hex
+        }
+
+        share_transfer.update(attrs)
+        share_transfer = osc_fakes.FakeResource(info=copy.deepcopy(
+            share_transfer),
+            methods=methods,
+            loaded=True)
+        return share_transfer
+
+    @staticmethod
+    def create_share_transfers(attrs=None, count=2):
+        """Create multiple fake transfers.
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :param Integer count:
+            The number of share transfers to be faked
+        :return:
+            A list of FakeResource objects
+        """
+
+        share_transfers = []
+        for n in range(0, count):
+            share_transfers.append(
+                FakeShareSnapshot.create_one_snapshot(attrs))
+
+        return share_transfers
+
+
 class FakeSnapshotAccessRule(object):
     """Fake one or more snapshot access rules"""
 
@@ -891,6 +952,66 @@ class FakeShareService(object):
         return services
 
 
+class FakeShareSecurityService(object):
+    """Fake one or more share security service"""
+
+    @staticmethod
+    def create_fake_security_service(attrs=None, methods=None):
+        """Create a fake share security service
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :return:
+            A FakeResource object, with project_id, resource and so on
+        """
+
+        attrs = attrs or {}
+        methods = methods or {}
+
+        share_security_service_info = {
+            "created_at": datetime.datetime.now().isoformat(),
+            "description": 'description',
+            "dns_ip": '0.0.0.0',
+            "domain": 'fake.domain',
+            "id": uuid.uuid4().hex,
+            "name": 'name-' + uuid.uuid4().hex,
+            "ou": 'fake_OU',
+            "password": 'password',
+            "project_id": uuid.uuid4().hex,
+            "server": 'fake_hostname',
+            "default_ad_site": 'fake_default_ad_site',
+            "status": 'new',
+            "type": 'ldap',
+            "updated_at": datetime.datetime.now().isoformat(),
+            "user": 'fake_user',
+        }
+
+        share_security_service_info.update(attrs)
+        share_security_service = osc_fakes.FakeResource(info=copy.deepcopy(
+            share_security_service_info),
+            methods=methods,
+            loaded=True)
+        return share_security_service
+
+    @staticmethod
+    def create_fake_security_services(attrs=None, count=2):
+        """Create multiple fake security services.
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :param Integer count:
+            The number of share security services to be faked
+        :return:
+            A list of FakeResource objects
+        """
+
+        security_services = []
+        for n in range(count):
+            security_services.append(
+                FakeShareSecurityService.create_fake_security_service(attrs))
+        return security_services
+
+
 class FakeSharePools(object):
     """Fake one or more share pool"""
 
@@ -1130,6 +1251,7 @@ class FakeShareNetworkSubnet(object):
             "share_network_id": str(uuid.uuid4()),
             "share_network_name": str(uuid.uuid4()),
             "updated_at": datetime.datetime.now().isoformat(),
+            "properties": {},
         }
 
         share_network_subnet.update(attrs)
@@ -1290,3 +1412,112 @@ class FakeShareGroupType(object):
             share_group_types = FakeShareGroupType.share_group_types(count)
 
         return mock.Mock(side_effect=share_group_types)
+
+
+class FakeShareGroupSnapshot(object):
+    """Fake a share group snapshot"""
+
+    @staticmethod
+    def create_one_share_group_snapshot(attrs=None, methods=None):
+        """Create a fake share group snapshot
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :return:
+            A FakeResource object, with project_id, resource and so on
+        """
+
+        attrs = attrs or {}
+        methods = methods or {}
+
+        share_group_snapshot = {
+            'status': 'available',
+            'share_group_id': 'share-group-id-' + uuid.uuid4().hex,
+            'name': None,
+            'created_at': datetime.datetime.now().isoformat(),
+            "project_id": 'project-id-' + uuid.uuid4().hex,
+            'id': 'share-group-snapshot-id-' + uuid.uuid4().hex,
+            'description': None
+        }
+
+        share_group_snapshot.update(attrs)
+        share_group_snapshot = osc_fakes.FakeResource(info=copy.deepcopy(
+            share_group_snapshot),
+            methods=methods,
+            loaded=True)
+        return share_group_snapshot
+
+    @staticmethod
+    def create_share_group_snapshots(attrs=None, count=2):
+        """Create multiple fake share group snapshot.
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :param Integer count:
+            The number of share group snapshot to be faked
+        :return:
+            A list of FakeResource objects
+        """
+
+        share_group_snapshots = []
+        for n in range(0, count):
+            share_group_snapshots.append(
+                FakeShareGroupSnapshot.create_one_share_group_snapshot(attrs))
+        return share_group_snapshots
+
+
+class FakeShareServer(object):
+    """Fake a share server"""
+
+    @staticmethod
+    def create_one_server(attrs=None, methods=None):
+        """Create a fake share server
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :return:
+            A FakeResource object, with project_id, resource and so on
+        """
+
+        attrs = attrs or {}
+        methods = methods or {}
+
+        share_server = {
+            'id': str(uuid.uuid4()),
+            'project_id': uuid.uuid4().hex,
+            "updated_at": datetime.datetime.now().isoformat(),
+            'status': None,
+            'host': None,
+            'check_only': False,
+            'share_network_name': None,
+            'share_network_id': str(uuid.uuid4()),
+            'share_network_subnet_id': str(uuid.uuid4()),
+            'created_at': datetime.datetime.now().isoformat(),
+            'is_auto_deletable': False,
+            'identifier': str(uuid.uuid4())
+        }
+
+        share_server.update(attrs)
+        share_server = osc_fakes.FakeResource(info=copy.deepcopy(
+            share_server),
+            methods=methods,
+            loaded=True)
+        return share_server
+
+    @staticmethod
+    def create_share_servers(attrs=None, count=2):
+        """Create multiple fake servers.
+
+        :param dict attrs:
+            A dictionary with all attributes
+        :param int count:
+            The number of share server to be faked
+        :return:
+            A list of FakeResource objects
+        """
+        attrs = attrs or {}
+        share_servers = []
+        for n in range(count):
+            share_servers.append(
+                FakeShareServer.create_one_server(attrs))
+        return share_servers
